Crusade V: Helsinki Helsinki, Finland July 12th 2003 23 players Pekka Miettinen "The Nosferatu Is Your Friend!" (aka. Nosferatu- A Gate Too Far) Since the library has practically no cards that give additional votes (except the Elysium) it is essential to get as many votes into play as possible - with big Minion Taps it's not uncommon at all to have 8-9 votes in the late game (Harrod, Nikolaus, Sheldon, e.g.), which is usually enough to pass a referendum. In combat, the deck relies heavily on maneuvers gained from Thrown Gates and Swallowed by the Nights. In case the opponent seems to be able to handle long-range combat as well, the deck has some light damage-prevention. In general, though, it is best not to block actions/bleeds from combat-heavy decks, but rather to try to bloat quickly with Minion Taps and Parity Shifts. The deck placed second in Crusade: Helsinki IV, and first in Crusade: Helsinki V Crypt (12 cards, min=28, max=44, avg=8.83) ------------------------------------------ 4x Harrod 11 ANI CEL OBF POT aus pre inner circle Nosferatu:2 2x Sheldon, Lord of the Clog 9 ANI AUS OBF POT for justicar Nosferatu:1 2x Selma the Repugnant 8 OBF POT ani for prince Nosferatu:1 2x Murat 7 OBF POT ser prince Nosferatu:2 2x Nikolaus Vermeulen 7 POT ani for obf prince Nosferatu:2 Library (90 cards) Master (20) 4x Blood Doll 1x Elder Library 1x Elysium: The Arboretum 1x Elysium: The Palace of Versailles 2x Fortitude 1x Giant's Blood 1x Information Highway 2x Labyrinth, The 6x Minion Tap 1x Slum Hunting Ground Action (3) 3x Fifth Tradition: Hospitality Equipment (1) 1x Leather Jacket Political Action (16) 1x Ancient Influence 1x Banishment 5x Conservative Agitation 4x Kine Resources Contested 4x Parity Shift 1x Protect Thine Own Action Modifier (13) 2x Cloak the Gathering 3x Elder Impersonation 1x Faceless Night 2x Forgotten Labyrinth 5x Lost in Crowds Action Modifier/Combat (5) 5x Swallowed by the Night Reaction (14) 8x Second Tradition: Domain 1x Telepathic Misdirection 5x Wake with Evening's Freshness Combat (18) 2x Hidden Strength 3x Skin of Steel 3x Superior Mettle 10x Thrown Gate